@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
+  Copyright (C) 2001-2020 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -65,15 +65,21 @@ extern "C" {
   typedef struct osip_list osip_list_t;
 
 /**
- * Structure used to iterate list.
- * @var osip_list_iterator_t
- */
-  typedef struct {
+  * Structure used to iterate list.
+  * @var osip_list_iterator_t
+  */
+  typedef struct osip_list_iterator osip_list_iterator_t;
+
+/**
+  * Structure used to iterate list.
+  * @struct osip_list_iterator
+  */
+  struct osip_list_iterator {
     __node_t *actual; /**< actual */
     __node_t **prev;  /**< prev */
     osip_list_t *li;  /**< li */
     int pos;          /**< pos */
-  } osip_list_iterator_t;
+  };
 
 /**
  * Structure for referencing a list of elements.
@@ -157,7 +163,7 @@ extern "C" {
  * @param li The element to work on.
  * @param it The iterator.
  */
-  void *osip_list_get_first (osip_list_t * li, osip_list_iterator_t * it);
+  void *osip_list_get_first (const osip_list_t * li, osip_list_iterator_t * it);
 /**
  * GEt next iterator.
  * @param it The element to work on.
