@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
+  Copyright (C) 2001-2020 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -70,9 +70,7 @@ extern "C" {
 #endif
     osip_list_t authorizations;                   /**< Authorizations headers */
     osip_call_id_t *call_id;                      /**< Call-ID header */
-#ifndef MINISIZE
     osip_list_t call_infos;                       /**< Call-Infos header */
-#endif
     osip_list_t contacts;                         /**< Contacts headers */
 #ifndef MINISIZE
     osip_list_t content_encodings;                /**< Content-Encodings headers */
@@ -151,6 +149,8 @@ extern "C" {
   int osip_message_parse_sipfrag (osip_message_t * sip, const char *buf, size_t length);
 /**
  * Get a string representation of a osip_message_t element.
+ * NOTE: You need to release the sip buffer returned by this API when you
+ * are done with the buffer. ie: osip_free(dest)
  * @param sip The element to work on.
  * @param dest new allocated buffer returned.
  * @param message_length The length of the returned buffer.
@@ -159,6 +159,8 @@ extern "C" {
 /**
  * Get a string representation of a message/sipfrag part
  * stored in an osip_message_t element.
+ * NOTE: You need to release the sip buffer returned by this API when you
+ * are done with the buffer. ie: osip_free(dest)
  * @param sip The element to work on.
  * @param dest new allocated buffer returned.
  * @param message_length The length of the returned buffer.
